# Licensed under a 3-clause BSD style license - see LICENSE.rst
# -*- coding: utf-8 -*-
"""
This subpackage corresponds to the fits directory in the Goddard utilities.
"""
from .mrdfits import mrdfits
